@@ -25,14 +25,14 @@ use utf8;
 use ClearPress::Localize;
 use MIME::Base64 qw(encode_base64);
 
-our $VERSION = q[473.0.1];
+our $VERSION = q[473.0.2];
 our $DEBUG_OUTPUT   = 0;
 our $TEMPLATE_CACHE = {};
 our $LEXICON_CACHE  = {};
 
 __PACKAGE__->mk_accessors(qw(util model action aspect content_type entity_name autoescape charset decorator));
 
-sub new {
+sub new { ## no critic (Complexity)
   my ($class, $self)    = @_;
   $self               ||= {};
   bless $self, $class;
